[![GitHub license](https://img.shields.io/github/license/Green-Phys/green-igen?cacheSeconds=3600&color=informational&label=License)](./LICENSE)
[![GitHub license](https://img.shields.io/badge/C%2B%2B-17-blue)](https://en.cppreference.com/w/cpp/compiler_support/17)

```
 █▀▀█ █▀▀█ █▀▀ █▀▀ █▀▀▄
 █ ▄▄ █▄▄▀ █▀▀ █▀▀ █  █
 █▄▄█ ▀ ▀▀ ▀▀▀ ▀▀▀ ▀  ▀
```
***

`Green/IntegralGeneration` is a part of Green Software Toolkit and uses modified PySCF code
to generate Ewald correction into Coulomb integrals.

# Installation

## Dependencies

`Green/IntegralGeneration` has the following required external dependencies
  - HDF5 library version >= 1.10.2
  - PySCF
  - NumPy
  - SciPy
  - h5py

## Installation of Python package

We provide pre-built binaries for major Linux distributions and recent MacOS version via `pip`.
For installation using `pip `simply type `pip install green-igen`.
If pre-built binaries can not be used, package will be built from sources.

# Acknowledgements

This work is supported by National Science Foundation under the award OCA-2310582
